@@ -7,6 +7,15 @@ class straight_heater_metal_model(BaseModel):
     def __init__(self,info,settings):
         super().__init__(port_names=["o1","o2"], info=info, settings=settings)
         self.info_handler()
+        #Get waveguide mode data
+        with open(os.path.dirname(__file__) + os.sep + "../waveguides/Si_strip_C_band.pkl",'rb') as f:
+            storage_dict = pickle.load(f)
+            width_sweep = np.array([i['width'] for i in storage_dict['TE0']])
+            neff_sweep = np.array([np.real(i['neff']) for i in storage_dict['TE0']])
+            ng_sweep = np.array([np.real(i['ng']) for i in storage_dict['TE0']])
+        self.neff = np.interp(self.width,width_sweep,neff_sweep)
+        self.ng = np.interp(self.width,width_sweep,ng_sweep)
+        self.dneff_dlambda = (self.neff - self.ng)/(1.55e-6)
         
         if self.with_undercut == False:
             filename = os.path.dirname(__file__) + os.sep + "TiN_heater_sweep.pkl"
@@ -35,6 +44,7 @@ class straight_heater_metal_model(BaseModel):
         except:
             self.with_undercut = True
         self.length = self.settings['length']*1e-6
+        self.width = 500e-9 #TODO: Find a way to extract the waveguide width
         return super().info_handler()
 
     def update_voltage(self,voltage):
@@ -43,7 +53,8 @@ class straight_heater_metal_model(BaseModel):
     def __call__(self):
         power_dissipated = self.voltage**2/self.resistance
         deltaphi = np.pi*power_dissipated/self.Ppi
+        phi = 2 * np.pi * (self.neff + (self.wl - 1.55e-6)*self.dneff_dlambda) * self.length/self.wl
         return {
-            ("o1","o2"): np.exp(-self.alpha*self.length/2 + 1j*deltaphi),
-            ("o2","o1"): np.exp(-self.alpha*self.length/2 + 1j*deltaphi)
+            ("o1","o2"): np.exp(-self.alpha*self.length/2 + 1j*(phi + deltaphi)),
+            ("o2","o1"): np.exp(-self.alpha*self.length/2 + 1j*(phi + deltaphi))
         }
\ No newline at end of file
